import * as React from "react";
import { unstable_SealedInitialState } from "../utils/useSealedState";
declare type Stop = {
    id: string;
    ref: React.RefObject<HTMLElement>;
};
export declare type RoverState = {
    /**
     * Defines the orientation of the rover list.
     */
    orientation?: "horizontal" | "vertical";
    /**
     * A list of element refs and IDs of the roving items.
     */
    stops: Stop[];
    /**
     * The current focused element ID.
     */
    currentId: Stop["id"] | null;
    /**
     * The last focused element ID.
     * @private
     */
    unstable_pastId: Stop["id"] | null;
    /**
     * If enabled, the next item after the last one will be the first one.
     */
    loop: boolean;
};
export declare type RoverActions = {
    /**
     * Registers the element ID and ref in the roving tab index list.
     */
    register: (id: Stop["id"], ref: Stop["ref"]) => void;
    /**
     * Unregisters the roving item.
     */
    unregister: (id: Stop["id"]) => void;
    /**
     * Moves focus onto a given element ID.
     */
    move: (id: Stop["id"] | null) => void;
    /**
     * Moves focus onto the next element.
     */
    next: () => void;
    /**
     * Moves focus onto the previous element.
     */
    previous: () => void;
    /**
     * Moves focus onto the first element.
     */
    first: () => void;
    /**
     * Moves focus onto the last element.
     */
    last: () => void;
    /**
     * Resets `currentId` and `pastId` states.
     * @private
     */
    unstable_reset: () => void;
    /**
     * Changes the `orientation` state of the roving tab index list.
     * @private
     */
    unstable_orientate: (orientation: RoverState["orientation"]) => void;
};
export declare type RoverInitialState = Partial<Pick<RoverState, "orientation" | "currentId" | "loop">>;
export declare type RoverStateReturn = RoverState & RoverActions;
export declare function useRoverState(initialState?: unstable_SealedInitialState<RoverInitialState>): RoverStateReturn;
export declare namespace useRoverState {
    var __keys: ("move" | "orientation" | "stops" | "currentId" | "unstable_pastId" | "loop" | "register" | "unregister" | "next" | "previous" | "first" | "last" | "unstable_reset" | "unstable_orientate")[];
}
export {};
